@@ -51,6 +51,7 @@ from .types.translation_config import (
     SnowflakeDialect,
     SourceEnv,
     SparkSQLDialect,
+    SQLServerDialect,
     TeradataDialect,
     TranslationConfigDetails,
     VerticaDialect,
@@ -85,6 +86,7 @@ __all__ = (
     "Point",
     "RedshiftDialect",
     "ResourceErrorDetail",
+    "SQLServerDialect",
     "SnowflakeDialect",
     "SourceEnv",
     "SparkSQLDialect",
