@@ -42,6 +42,7 @@ from .translation_config import (
     SnowflakeDialect,
     SourceEnv,
     SparkSQLDialect,
+    SQLServerDialect,
     TeradataDialect,
     TranslationConfigDetails,
     VerticaDialect,
@@ -81,6 +82,7 @@ __all__ = (
     "SnowflakeDialect",
     "SourceEnv",
     "SparkSQLDialect",
+    "SQLServerDialect",
     "TeradataDialect",
     "TranslationConfigDetails",
     "VerticaDialect",
