@@ -120,7 +120,9 @@ class MigrationTask(proto.Message):
             types: Translation_Teradata2BQ, Translation_Redshift2BQ,
             Translation_Bteq2BQ, Translation_Oracle2BQ,
             Translation_HiveQL2BQ, Translation_SparkSQL2BQ,
-            Translation_Snowflake2BQ, Translation_Netezza2BQ.
+            Translation_Snowflake2BQ, Translation_Netezza2BQ,
+            Translation_AzureSynapse2BQ, Translation_Vertica2BQ,
+            Translation_SQLServer2BQ.
         state (google.cloud.bigquery_migration_v2.types.MigrationTask.State):
             Output only. The current state of the task.
         processing_error (google.rpc.error_details_pb2.ErrorInfo):
