@@ -30,6 +30,7 @@ __protobuf__ = proto.module(
         "NetezzaDialect",
         "AzureSynapseDialect",
         "VerticaDialect",
+        "SQLServerDialect",
         "ObjectNameMappingList",
         "ObjectNameMapping",
         "NameMappingKey",
@@ -155,6 +156,10 @@ class Dialect(proto.Message):
         vertica_dialect (google.cloud.bigquery_migration_v2.types.VerticaDialect):
             The Vertica dialect
 
+            This field is a member of `oneof`_ ``dialect_value``.
+        sql_server_dialect (google.cloud.bigquery_migration_v2.types.SQLServerDialect):
+            The SQL Server dialect
+
             This field is a member of `oneof`_ ``dialect_value``.
     """
 
@@ -218,6 +223,12 @@ class Dialect(proto.Message):
         oneof="dialect_value",
         message="VerticaDialect",
     )
+    sql_server_dialect = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        oneof="dialect_value",
+        message="SQLServerDialect",
+    )
 
 
 class BigQueryDialect(proto.Message):
@@ -278,6 +289,10 @@ class VerticaDialect(proto.Message):
     r"""The dialect definition for Vertica."""
 
 
+class SQLServerDialect(proto.Message):
+    r"""The dialect definition for SQL Server."""
+
+
 class ObjectNameMappingList(proto.Message):
     r"""Represents a map of name mappings using a list of key:value
     proto messages of existing name to desired output name.
