@@ -13,21 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.cloud.bigquery_migration_v2alpha.types import migration_entities
-from google.cloud.bigquery_migration_v2alpha.types import migration_service
-from google.protobuf import empty_pb2  # type: ignore
-from .base import MigrationServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.bigquery_migration_v2alpha.types import (
+    migration_entities,
+    migration_service,
+)
+
+from .base import DEFAULT_CLIENT_INFO, MigrationServiceTransport
 
 
 class MigrationServiceGrpcTransport(MigrationServiceTransport):
@@ -433,5 +434,9 @@ class MigrationServiceGrpcTransport(MigrationServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("MigrationServiceGrpcTransport",)
